@@ -1,15 +1,9 @@
-
-// includes from the plugin
 #include <RcppArmadillo.h>
-#include <Rcpp.h>
+// [[Rcpp::depends(RcppArmadillo)]]
 
-#ifndef BEGIN_RCPP
-#define BEGIN_RCPP
-#endif
 
-#ifndef END_RCPP
-#define END_RCPP
-#endif
+// #include <Rcpp.h>
+
 
 using namespace Rcpp;
 
@@ -23,55 +17,33 @@ using namespace Rcpp;
 //*************************************************************************
 //*************************************************************************
 
-
-
-// declarations
-extern "C" {
-SEXP bifie_jack_timss( SEXP wgt_, SEXP jkzone_, SEXP jkrep_, SEXP RR_, 
-	  SEXP jkfac_, SEXP prbar_) ;
-}
-
-// definition
-
-SEXP bifie_jack_timss( SEXP wgt_, SEXP jkzone_, SEXP jkrep_, SEXP RR_, 
-	 SEXP jkfac_, SEXP prbar_ ){
-BEGIN_RCPP
-   
+// [[Rcpp::export]]
+Rcpp::NumericMatrix bifie_jack_timss( Rcpp::NumericVector wgt, 
+        Rcpp::NumericVector jkzone, Rcpp::NumericVector jkrep , 
+        int RR, double jkfac, Rcpp::NumericVector prbar ){
+                     
+    int N = wgt.size() ;         
+    Rcpp::NumericMatrix wgtrep(N,RR);  
        
-       
-     Rcpp::NumericVector wgt(wgt_);  
-     Rcpp::NumericVector jkzone(jkzone_);  
-     Rcpp::NumericVector jkrep(jkrep_);  
-     int RR = as<int>(RR_);  
-     double jkfac = as<double>(jkfac_) ;  
-     Rcpp::NumericVector prbar(prbar_);  
-       
-     int N = wgt.size() ;  
-       
-     Rcpp::NumericMatrix wgtrep(N,RR);  
-       
-     for (int rr=0;rr<RR;rr++){  
-     for (int nn=0;nn<N;nn++){  
-     if ( jkzone[nn] == rr ){  
-     	wgtrep(nn,rr) = jkfac * wgt[nn] * jkrep[nn] ;  
-     			} else {  
-     	wgtrep(nn,rr) = wgt[nn] ;  
-     			}  
+    for (int rr=0;rr<RR;rr++){  
+        for (int nn=0;nn<N;nn++){  
+            if ( jkzone[nn] == rr ){  
+     	      wgtrep(nn,rr) = jkfac * wgt[nn] * jkrep[nn] ;  
+     		} else {  
+     	      wgtrep(nn,rr) = wgt[nn] ;  
      		}  
-     if (prbar[rr] == 1){		  
-     	Rcpp::Rcout << "-" <<  std::flush  ;  
-     		}  
-     		  
      	}  
-       
-     return( wrap( wgtrep) ) ;  
-       
-       
-       
-     // Rcpp::Rcout << "tmp1 " <<  tmp1 <<  std::flush << std::endl ;
-END_RCPP
+        if (prbar[rr] == 1){		  
+     	  Rcpp::Rcout << "-" <<  std::flush  ;  
+     	}  
+    }  
+    return( wgtrep ) ;                
 }
 
+     // Rcpp::Rcout << "tmp1 " <<  tmp1 <<  std::flush << std::endl ;
+
+
+
 //*************************************************************************
 //*************************************************************************
 //*************************************************************************
@@ -80,21 +52,9 @@ END_RCPP
 //*************************************************************************
 //*************************************************************************
 
-
-// declarations
-extern "C" {
-SEXP bifie_boot( SEXP cumwgt_, SEXP rand_wgt_) ;
-}
-
-// definition
-
-SEXP bifie_boot( SEXP cumwgt_, SEXP rand_wgt_ ){
-BEGIN_RCPP
-   
-       
-     Rcpp::NumericVector cumwgt(cumwgt_);          
-     Rcpp::NumericMatrix rand_wgt(rand_wgt_) ;  
-       
+// [[Rcpp::export]]
+Rcpp::List bifie_boot( Rcpp::NumericVector cumwgt , Rcpp::NumericMatrix rand_wgt ){
+ 
      int N = cumwgt.size() ;  
      int WW = rand_wgt.ncol() ;  
        
@@ -105,23 +65,21 @@ BEGIN_RCPP
      int nn1=0;  
        
      for (int ww=0;ww<WW;ww++){  
-     for (int nn=0;nn<N;nn++){  
-     	wgt_temp(nn,0) = rand_wgt(nn,ww) ;  
-     			}  
-     // sort entries  
-     arma::colvec wgt_tempsort = arma::sort( wgt_temp ) ;  
-       
-     zz=0;  
-     nn1=0;  
-       
-     while (nn1<N){  
-     	if (wgt_tempsort(nn1,0) < cumwgt[zz] ){  
-     		wgtM(zz,ww) ++ ;  
-     		nn1 ++ ;	  
-     		} else {  
-     		zz ++ ;   
-     		}  
-     	}  
+       for (int nn=0;nn<N;nn++){  
+       	    wgt_temp(nn,0) = rand_wgt(nn,ww) ;  
+       	}  
+       // sort entries  
+       arma::colvec wgt_tempsort = arma::sort( wgt_temp ) ;           
+       zz=0;  
+       nn1=0;           
+       while (nn1<N){  
+       	if (wgt_tempsort(nn1,0) < cumwgt[zz] ){  
+       		wgtM(zz,ww) ++ ;  
+       		nn1 ++ ;	  
+       		} else {  
+       		zz ++ ;   
+       		}  
+       	}  
      }  
      	  
      //*************************************************      
@@ -131,11 +89,7 @@ BEGIN_RCPP
          Rcpp::_["rand_wgt"] = rand_wgt ,  
          Rcpp::_["wgtM"] = wgtM      
          ) ;    
-     // maximal list length is 20!  
-              
-     // Rcpp::Rcout << "tmp1 " <<  tmp1 <<  std::flush << std::endl ;  
                   
-END_RCPP
 }
 
 //*************************************************************************
@@ -146,22 +100,10 @@ END_RCPP
 //*************************************************************************
 //*************************************************************************
 
+// [[Rcpp::export]]
+Rcpp::List bifie_bifiedata2bifiecdata( Rcpp::NumericMatrix datalistM , int Nimp ){
 
-// declarations
-extern "C" {
-SEXP bifie_bifiedata2bifiecdata( SEXP datalistM_, SEXP Nimp_) ;
-}
-
-// definition
-
-SEXP bifie_bifiedata2bifiecdata( SEXP datalistM_, SEXP Nimp_ ){
-BEGIN_RCPP
-   
-       
-     Rcpp::NumericMatrix datalistM(datalistM_);          
-     int Nimp=as<int>(Nimp_);       
-       
-     int N= datalistM.nrow() / Nimp ;  
+     int N = datalistM.nrow() / Nimp ;  
      int VV = datalistM.ncol() ;  
        
      //************************************************  
@@ -202,32 +144,29 @@ BEGIN_RCPP
      Rcpp::IntegerMatrix datalistM_impindex(ZZ,2);  
      // first column: subject case  
      // second column: imputed variable  
-       
-       
+              
      int zz=0;  
      for (int vv=0;vv<VV;vv++){  
-     for (int nn=0;nn<N;nn++){  
-     if ( ! R_IsNA( datalistM(nn , vv ) ) ){	  
-     if ( datalistM_ind(nn,vv) == 0 ){ // beg if missing entry  
-     	datalistM_impindex(zz,0)=nn;  
-     	datalistM_impindex(zz,1)=vv;				  
-     	for (int ii=0;ii<Nimp;ii++){  // beg ii  
-     	//	datalistM_imputed(zz,0) = ii;  
-     	//	datalistM_imputed(zz,1) = nn;	  
-     	//	datalistM_imputed(zz,2) = vv;	  
-     	//	datalistM_imputed(zz,3) = datalistM( nn+ii*N , vv) ;  
-     	datalistM_imputed(zz,ii) = datalistM(nn+ii*N , vv ) ;		  
-     				} // end ii  
-     	zz ++ ;			  
-     		}	// end if missing entry  
-     }  
-     } // end nn  
+       for (int nn=0;nn<N;nn++){  
+         if ( ! R_IsNA( datalistM(nn , vv ) ) ){	  
+           if ( datalistM_ind(nn,vv) == 0 ){ // beg if missing entry  
+             	datalistM_impindex(zz,0)=nn;  
+             	datalistM_impindex(zz,1)=vv;				  
+             	for (int ii=0;ii<Nimp;ii++){  // beg ii  
+                 	//	datalistM_imputed(zz,0) = ii;  
+                 	//	datalistM_imputed(zz,1) = nn;	  
+                 	//	datalistM_imputed(zz,2) = vv;	  
+                 	//	datalistM_imputed(zz,3) = datalistM( nn+ii*N , vv) ;  
+                 	datalistM_imputed(zz,ii) = datalistM(nn+ii*N , vv ) ;		  
+             	} // end ii  
+             	zz ++ ;			  
+           }	// end if missing entry  
+         }  // end R_IsNA 
+       } // end nn  
      } // end vv  
-       
-     	  
+           	  
      //*************************************************      
-     // OUTPUT              
-               
+     // OUTPUT                             
      return Rcpp::List::create(   
          Rcpp::_["datalistM_ind"] = datalistM_ind ,  
          Rcpp::_["datalistM_imputed"] = datalistM_imputed ,  
@@ -235,18 +174,10 @@ BEGIN_RCPP
          Rcpp::_["Nimp"] = Nimp ,  
          Rcpp::_["Nmiss"] = Nmiss  
          ) ;    
-       
-     // maximal list length is 20!  
-       
-       
-     // Rcpp::Rcout << "tmp1 " <<  tmp1 <<  std::flush << std::endl ;  
-       
-       
-     
-END_RCPP
 }
 
 
+
 //*************************************************************************
 //*************************************************************************
 //*************************************************************************
@@ -255,53 +186,34 @@ END_RCPP
 //*************************************************************************
 //*************************************************************************
 
-
-// declarations
-extern "C" {
-SEXP bifie_bifiecdata2bifiedata( SEXP datalistM_ind_, SEXP datalistM_imputed_, 
-	SEXP Nimp_, SEXP dat1_, SEXP datalistM_impindex_) ;
-}
-
-// definition
-
-SEXP bifie_bifiecdata2bifiedata( SEXP datalistM_ind_, SEXP datalistM_imputed_, 
-	SEXP Nimp_, SEXP dat1_, SEXP datalistM_impindex_ ){
-BEGIN_RCPP
-   
-       
-     Rcpp::NumericMatrix datalistM_ind(datalistM_ind_);  
-     Rcpp::NumericMatrix datalistM_imputed(datalistM_imputed_);  
-     int Nimp=as<int>(Nimp_);       
-     Rcpp::NumericMatrix dat1(dat1_);  
-     Rcpp::NumericMatrix datalistM_impindex(datalistM_impindex_);  
-       
-       
+// [[Rcpp::export]]
+Rcpp::List bifie_bifiecdata2bifiedata( Rcpp::NumericMatrix datalistM_ind, 
+      Rcpp::NumericMatrix datalistM_imputed , 
+	  int Nimp, Rcpp::NumericMatrix dat1, Rcpp::NumericMatrix datalistM_impindex ){
+  
      int N=dat1.nrow();  
      int VV=dat1.ncol();  
-     int ZZ=Nimp*N;  
-       
+     int ZZ=Nimp*N;         
      Rcpp::NumericMatrix datalistM(ZZ,VV);  
        
      //**** non-imputed data  
      for (int ii=0;ii<Nimp;ii++){   // beg ss  
-     for (int nn=0;nn<N;nn++){ // beg nn  
-        for (int vv=0;vv<VV;vv++){	// beg vv  
-     	if ( datalistM_ind(nn,vv) == 1 ){ // beg non-imputed data  
-     		datalistM(nn+ii*N,vv) = dat1(nn,vv) ;  
-     				}  // end non-imputed data			  
-     			} // end vv  
-     		} // end nn  
-           } // end ss  
+       for (int nn=0;nn<N;nn++){ // beg nn  
+          for (int vv=0;vv<VV;vv++){	// beg vv  
+         	if ( datalistM_ind(nn,vv) == 1 ){ // beg non-imputed data  
+         		datalistM(nn+ii*N,vv) = dat1(nn,vv) ;  
+         				}  // end non-imputed data			  
+          } // end vv  
+       	} // end nn  
+    } // end ss  
        
              
      //**** imputed data  
      //--- Rcpp::NumericMatrix datalistM_imputed(ZZ,4);  
      // 	first column: subject case  
      // 	second column: imputed variable  
-       
-       
-     int HH=datalistM_imputed.nrow();  
-     // int ii_ ;  
+              
+     int HH=datalistM_imputed.nrow();   
      int nn_ ;  
      int vv_ ;  
        
@@ -309,28 +221,19 @@ BEGIN_RCPP
         nn_ = datalistM_impindex(hh,0) ;	  
         vv_ = datalistM_impindex(hh,1) ;	  
         for (int ii=0;ii<Nimp;ii++){		  
-     //	ii_ = datalistM_imputed(hh,0) ;  
              datalistM( nn_ + ii * N , vv_ ) = datalistM_imputed(hh, ii ) ;  
      			}	  
      }                                  
              
      //*************************************************      
-     // OUTPUT              
-               
+     // OUTPUT                             
      return Rcpp::List::create(   
          Rcpp::_["datalistM"] = datalistM  ,       
          Rcpp::_["Nimp"] = Nimp     
-         ) ;    
-       
-     // maximal list length is 20!         
-       
-     // Rcpp::Rcout << "tmp1 " <<  tmp1 <<  std::flush << std::endl ;                                                        
-     
-END_RCPP
+         ) ;          
 }
 
 
-
 //*************************************************************************
 //*************************************************************************
 //*************************************************************************
@@ -340,22 +243,10 @@ END_RCPP
 //*************************************************************************
 //*************************************************************************
 
-
-// declarations
-extern "C" {
-SEXP bifie_bifiedata_stepwise( SEXP dat_, SEXP dat_ind_, SEXP Nmiss_) ;
-}
-
-// definition
-
-SEXP bifie_bifiedata_stepwise( SEXP dat_, SEXP dat_ind_, SEXP Nmiss_ ){
-BEGIN_RCPP
-   
-       
-     Rcpp::NumericMatrix dat1(dat_);  
-     Rcpp::NumericMatrix dat_ind(dat_ind_);  
-     int Nmiss = as<int>(Nmiss_) ;  
-       
+// [[Rcpp::export]]
+Rcpp::List bifie_bifiedata_stepwise( Rcpp::NumericMatrix dat1, 
+      Rcpp::NumericMatrix dat_ind , int Nmiss ){
+  
      int N=dat1.nrow();  
      int VV=dat1.ncol();  
        
@@ -380,31 +271,13 @@ BEGIN_RCPP
      	}	// end if missing entry  
      } // end nn  
      } // end vv  
-       
-       
-       
-     //*************************************************      
-     // OUTPUT              
                
+     //*************************************************      
+     // OUTPUT                             
      return Rcpp::List::create(   
          Rcpp::_["datalistM_imputed"] = datalistM_imputed // ,      
-         ) ;    
-       
-     // maximal list length is 20!  
-       
-       
-     // Rcpp::Rcout << "tmp1 " <<  tmp1 <<  std::flush << std::endl ;  
-       
-       
-     
-END_RCPP
+         ) ;           
 }
 
 
 
-
-
-
-
-
-
